﻿using UnityEngine;
using System.Collections.Generic;

public class Character : MonoBehaviour {
    
    Vector3 m_moveDir = Vector3.zero;
    Rigidbody m_rb;

    float m_brake = 2;
    float m_maxSpeed = 3;
    float m_acceleration = 5;

    public GameObject m_echoObj;
    BarProgress m_echoCooldownBar;
    List<Echo> m_echos = new List<Echo>();
    Timer m_echoCooldown;
    float m_echoCooldownValue = 500;
    public bool m_canEcho = true;

    AudioSource m_audio;
    public AudioClip m_audWalk, m_audRun;
    Timer m_stepTimer;

    bool m_isWalking = false, m_startedMoving = false;

    public bool isWalking { get { return m_isWalking; } }

	// Use this for initialization
	void Start () {
        m_rb = GetComponent<Rigidbody>();

        m_echoCooldown = gameObject.AddComponent<Timer>();
        m_echoCooldown.PushCallback(ResetEcho);

        m_echoCooldownBar = GameObject.Find("bpEcho").GetComponent<BarProgress>();

        m_audio = GetComponent<AudioSource>();
        m_stepTimer = gameObject.AddComponent<Timer>();
        m_stepTimer.PushCallback(DoStep);
	}
	
	// Update is called once per frame
	void Update () {
        CheckInput();

        Vector3 m_targetSpeed = m_moveDir * m_maxSpeed * ((m_isWalking) ? .25f : 1);

        m_rb.velocity = Vector3.Lerp(m_rb.velocity, m_targetSpeed, Time.deltaTime * m_acceleration);

        transform.forward = Vector3.Lerp(transform.forward, m_moveDir, Time.deltaTime * 8);

        if(m_echoCooldown.running)
            m_echoCooldownBar.barFill = (m_echoCooldown.value / m_echoCooldown.duration);

        if (IsMoving() && !m_startedMoving)
        {
            DoStep();
            m_startedMoving = true;
        }
        else if (!IsMoving())
        {
            m_stepTimer.Stop();
            m_audio.Stop();
            m_startedMoving = false;
        }
	}

    bool IsMoving()
    {
        return (m_moveDir != Vector3.zero);
    }

    void CheckInput()
    {
        if (Input.GetKey(KeyCode.W))
            m_moveDir.z = 1;
        else if (Input.GetKey(KeyCode.S))
            m_moveDir.z = -1;
        else
            m_moveDir.z = 0;

        if (Input.GetKey(KeyCode.W) && Input.GetKey(KeyCode.S))
            m_moveDir.z = 0;

        if (Input.GetKey(KeyCode.A))
            m_moveDir.x = -1;
        else if (Input.GetKey(KeyCode.D))
            m_moveDir.x = 1;
        else
            m_moveDir.x = 0;

        if (Input.GetKey(KeyCode.A) && Input.GetKey(KeyCode.D))
            m_moveDir.x = 0;


        //CREATE AN ECHO
        if (Input.GetKeyDown(KeyCode.Space) && m_canEcho)
        {
            CreateEcho();
            m_canEcho = false;
            m_echoCooldown.Start(m_echoCooldownValue);
        }

        m_isWalking = (Input.GetKey(KeyCode.LeftShift));
    }

    void CreateEcho()
    {
        GameObject echo = Instantiate(m_echoObj);

        echo.transform.position = transform.position;
    }

    void DoStep()
    {
        if (IsMoving())
        {
            if (isWalking)
            {
                m_audio.clip = m_audWalk;
                m_stepTimer.Start(500);
                Debug.Log("step walk");
            }
            else
            {
                m_audio.clip = m_audRun;
                m_stepTimer.Start(575);
            }


            m_audio.Play();
        }
    }

    void ResetEcho()
    {
        m_canEcho = true;
    }
}
