﻿using UnityEngine;
using System.Collections;

public class Echo : MonoBehaviour {

    SphereCollider m_collider;
    MeshRenderer m_renderer;

    float m_alpha = 1;
    bool m_fade = true, m_permaFade = false;
    float m_fadeSpeed = 7;

    float m_echoSpeed = 20;
    float m_maxRadius = 40;

    bool m_hidden = false;

	// Use this for initialization
	void Start () {
        m_collider = GetComponent<SphereCollider>();

        m_renderer = GetComponent<MeshRenderer>();
        m_renderer.material.SetColor("_EmissionColor", m_renderer.material.color);
	}
	
	// Update is called once per frame
	void Update () {

        if (!m_hidden)
        {
            Vector3 size = transform.localScale + Vector3.one * m_echoSpeed * Time.deltaTime;
            transform.localScale = size;
        }

        if (transform.localScale.magnitude >= m_maxRadius)
            m_permaFade = true;

        if (m_fade || m_permaFade)
        {
            if (m_alpha > 0)
                m_alpha -= m_fadeSpeed * Time.deltaTime;
            else
            {
                m_fade = false;

                if (m_permaFade)
                    Destroy(gameObject);
            }
        }
        else
        {
            if (m_alpha < 1)
                m_alpha += m_fadeSpeed * Time.deltaTime;
            else
                m_fade = true;
        }

        Color col = m_renderer.material.color;

        col.a = m_alpha;

        m_renderer.material.color = col;
    }

    void OnTriggerEnter(Collider col)
    {
        Echoable check = col.GetComponent<Echoable>();
        Prey preyCheck = col.GetComponent<Prey>();

        if (check)
            check.CheckForVisible(this);

        if (preyCheck)
            preyCheck.Scare(this);
    }

    public void Hide()
    {
        m_collider.enabled = false;
        m_hidden = true;
    }

    public void Show()
    {
        m_collider.enabled = true;
        m_hidden = false;
    }
}
