﻿using UnityEngine;
using System.Collections;

[RequireComponent(typeof(Rigidbody))]

public class Echoable : MonoBehaviour {

    protected MeshRenderer[] m_renderers;

    protected Character m_player;
    Timer m_timer;

    protected bool shown = false;

	// Use this for initialization
	protected virtual void Start () {

        m_renderers = GetComponentsInChildren<MeshRenderer>();

        Hide();

        m_player = GameObject.Find("Player").GetComponent<Character>();

        Rigidbody rb = GetComponent<Rigidbody>();
        
        rb.constraints = RigidbodyConstraints.FreezeAll;
        rb.useGravity = false;

        m_timer = gameObject.AddComponent<Timer>();
        m_timer.PushCallback(Hide);
	}
	
	// Update is called once per frame
	protected virtual void Update () {
	
	}

    public bool CheckForVisible(Echo a_echo)
    {
        a_echo.Hide();

        Vector3 dirToPlayer = m_player.transform.position-transform.position;

        RaycastHit hit;

        

        if(Physics.Raycast(transform.position, dirToPlayer, out hit))
        {
            Character check = hit.transform.GetComponent<Character>();

            if (check)
            {
                Show();
                a_echo.Show();
                m_timer.Start(500);
                Debug.DrawRay(transform.position, dirToPlayer, Color.green);

                return true;
            }
        }

        a_echo.Show();

        return false;
    }

    protected virtual void Show()
    {
        foreach (MeshRenderer r in m_renderers)
        {
            Color col = r.material.color;

            col.a = 1;

            r.material.color = col;

            r.enabled = true;
        }

        shown = true;
    }

    protected void Hide()
    {
        foreach (MeshRenderer r in m_renderers)
            r.enabled = false;

        shown = false;
    }
}
